.. include:: global.rst

Citing |masai|
===============

When using |masai| for your own work, and before a paper is published on this software, you are kindly requested to cite it this way::

	Christian Fernandez, masaï: a framework for processing, analysing and modelling of solid state NMR spectra, 
	http://fernandezc.github.com/masai, 
	version 0.1, Laboratoire Catalyse et Spectrochimie - ENSICAEN/Université de Caen/CNRS, 2012

